@@ -10,7 +10,7 @@ rdsf <- function(x)
 
 local({
   update_fastlm(.unitizer.fastlm, version="0.1.0")
-  devtools::install(.unitizer.fastlm, quick=TRUE, quiet=TRUE, local=FALSE)
+  install.packages(.unitizer.fastlm, repos=NULL, type='src', quiet=TRUE)
   base.dir <- file.path(.unitizer.fastlm, "tests", "extra")
   in.pkg.file <- file.path(base.dir, "inpkg.R")
   old.opt <- options(width=80L)
